@@ -347,7 +347,6 @@ class ZabbixAPI():
             headers=headers,
             method='POST'
         )
-        req.timeout = self.timeout
 
         # Disable SSL certificate validation if needed.
         if not self.validate_certs:
@@ -360,7 +359,7 @@ class ZabbixAPI():
             ctx = None
 
         try:
-            resp = ul.urlopen(req, context=ctx)
+            resp = ul.urlopen(req, context=ctx, timeout=self.timeout)
             resp_json = json.loads(resp.read().decode('utf-8'))
         except URLError as err:
             raise ProcessingError(f"Unable to connect to {self.url}:", err) from None
